@@ -80,6 +80,6 @@ angleBetweenDirs :: (Metric v, Floating n, Ord n)
   => Direction v n -> Direction v n -> Angle n
 angleBetweenDirs d1 d2 = angleBetween (fromDirection d1) (fromDirection d2)
 
--- | @dirBetween p q@ returns the directions from @p@ to @q@
+-- | @dirBetween p q@ returns the direction from @p@ to @q@.
 dirBetween :: (Additive v, Num n) => Point v n -> Point v n -> Direction v n
-dirBetween p q = dir $ p .-. q
+dirBetween p q = dir $ q .-. p
