@@ -1,5 +1,4 @@
-{-# LANGUAGE ConstraintKinds #-}
-{-# LANGUAGE CPP                   #-}
+{-# LANGUAGE ConstraintKinds       #-}
 {-# LANGUAGE DeriveDataTypeable    #-}
 {-# LANGUAGE FlexibleContexts      #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
@@ -41,10 +40,6 @@ module Diagrams.ThreeD.Shapes
   , difference
   ) where
 
-#if __GLASGOW_HASKELL__ < 710
-import           Control.Applicative
-import           Data.Foldable             (foldMap)
-#endif
 import           Control.Lens              (review, (^.), _1)
 import           Data.Typeable
 
@@ -255,11 +250,11 @@ instance Fractional n => Transformable (CSG n) where
 -- | The Envelope for an Intersection or Difference is simply the
 -- Envelope of the Union.  This is wrong but easy to implement.
 instance RealFloat n => Enveloped (CSG n) where
-  getEnvelope (CsgEllipsoid p) = getEnvelope p
-  getEnvelope (CsgBox p) = getEnvelope p
-  getEnvelope (CsgFrustum p) = getEnvelope p
-  getEnvelope (CsgUnion ps) = foldMap getEnvelope ps
-  getEnvelope (CsgIntersection ps) = foldMap getEnvelope ps
+  getEnvelope (CsgEllipsoid p)      = getEnvelope p
+  getEnvelope (CsgBox p)            = getEnvelope p
+  getEnvelope (CsgFrustum p)        = getEnvelope p
+  getEnvelope (CsgUnion ps)         = foldMap getEnvelope ps
+  getEnvelope (CsgIntersection ps)  = foldMap getEnvelope ps
   getEnvelope (CsgDifference p1 p2) = getEnvelope p1 <> getEnvelope p2
 -- TODO after implementing some approximation scheme, calculate
 -- correct (approximate) envelopes for intersections and difference.
